# Attribution Guidelines

We kindly request that any public use of the MCP Platform include a visible attribution to:

**MCP Platform** by [Data Everything](https://mcp-platform.dataeverything.io)
GitHub: https://github.com/Data-Everything/mcp-server-templates

### Why it matters

We are building this platform as a community-first initiative. Attribution helps the project grow, gain adoption, and evolve. We are not enforcing this — but your support means a lot.

### Commercial Use or Hosted Services

If you’d like to embed MCP Platform in a commercial offering or hosted service, please reach out to us at [tooling@dataeverything.ai](mailto:tooling@dataeverything.ai) to discuss a commercial license or partnership.

Thanks for supporting ethical and sustainable open-source!
